@@ -27,7 +27,9 @@ impl LockerParams {
             .min(self.max_stake_duration);
 
         // voting power at max lockup
-        let power_if_max_lockup = escrow.amount.checked_mul(self.max_stake_vote_multiplier)?;
+        let power_if_max_lockup = escrow
+            .amount
+            .checked_mul(self.max_stake_vote_multiplier.into())?;
 
         // multiply the max lockup power by the fraction of the max stake duration
         let power = (power_if_max_lockup as u128)
@@ -45,7 +47,8 @@ mod tests {
     use super::*;
     use proptest::prelude::*;
 
-    const ONE_YEAR: u64 = 365 * 24 * 60 * 60;
+    const ONE_DAY: u64 = 24 * 60 * 60;
+    const ONE_YEAR: u64 = 365 * ONE_DAY;
     /// Maximum seconds elapsed between two checkpoints.
     /// [i32::MAX] corresponds to about 70 years.
     const MAX_SECONDS_BETWEEN_CHECKPOINTS: i64 = i32::MAX as i64;
@@ -75,7 +78,7 @@ mod tests {
         let power = locker_params.calculate_voter_power(&escrow, 100).unwrap();
         assert_eq!(
             power,
-            escrow.amount * locker_params.max_stake_vote_multiplier,
+            escrow.amount * locker_params.max_stake_vote_multiplier as u64,
             "full power"
         );
 
@@ -83,7 +86,7 @@ mod tests {
             locker_params
                 .calculate_voter_power(&escrow, 100 + 2 * ONE_YEAR as i64)
                 .unwrap(),
-            escrow.amount * locker_params.max_stake_vote_multiplier / 2,
+            escrow.amount * locker_params.max_stake_vote_multiplier as u64 / 2,
             "half lockup"
         );
 
@@ -114,7 +117,7 @@ mod tests {
         let power = locker_params.calculate_voter_power(&escrow, 600).unwrap();
         assert_eq!(
             power,
-            escrow.amount * locker_params.max_stake_vote_multiplier
+            escrow.amount * locker_params.max_stake_vote_multiplier as u64
         );
     }
 
@@ -122,8 +125,8 @@ mod tests {
         #[test]
         fn test_lockup_with_zero_balance(
             current_ts in 0..=i64::MAX,
+            max_stake_vote_multiplier in 0..=u8::MAX,
             max_stake_duration_years in 0..=10u64,
-            max_stake_vote_multiplier in 0..=100u64,
             (escrow_ends_at, escrow_started_at) in total_and_intermediate_ts(),
         ) {
             let locker_params = &LockerParams {
